@@ -5,7 +5,7 @@ import { createServer } from 'http';
 import { addFacilityMiddleware } from './addFacilityMiddleware';
 import { sync as syncRoutes } from './routes/sync/sync';
 
-export async function createSyncApp({ sequelize, reportSchemaStores, syncManager, models, deviceId }) {
+export async function createSyncApp({ sequelize, syncManager, models, deviceId }) {
   const express = defineExpress();
   const server = createServer(express);
 
@@ -14,7 +14,6 @@ export async function createSyncApp({ sequelize, reportSchemaStores, syncManager
   express.use((req, res, next) => {
     req.models = models;
     req.db = sequelize;
-    req.reportSchemaStores = reportSchemaStores;
     req.syncManager = syncManager;
     req.deviceId = deviceId;
 
